==> apache-servicecomb-java-chassis-distribution-2.0.0-src.zip: apache-servicecomb-java-chassis-distribution-2.0.0-src/integration-tests/it-common/src/main/java/org/apache/servicecomb/it/schema/objectparams/ObjectParamTypeSchema.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.it.schema.objectparams;

import java.util.List;
import java.util.Map;

public interface ObjectParamTypeSchema {
  FlattenObjectResponse testFlattenObjectParam(FlattenObjectRequest request);

  MultiLayerObjectParam testMultiLayerObjectParam(MultiLayerObjectParam request);

  RecursiveObjectParam testRecursiveObjectParam(RecursiveObjectParam request);

  List<GenericObjectParam<List<RecursiveObjectParam>>> testListObjectParam(
      List<GenericObjectParam<List<RecursiveObjectParam>>> request);

  Map<String, GenericObjectParam<Map<String, GenericObjectParam<RecursiveObjectParam>>>> testMapObjectParam(
      Map<String, GenericObjectParam<Map<String, GenericObjectParam<RecursiveObjectParam>>>> request);
}

==> apache-servicecomb-java-chassis-distribution-2.7.6-src.zip: apache-servicecomb-java-chassis-distribution-2.7.6-src/integration-tests/it-common/src/main/java/org/apache/servicecomb/it/schema/objectparams/ObjectParamTypeSchema.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.it.schema.objectparams;

import java.util.List;
import java.util.Map;

public interface ObjectParamTypeSchema {
  FlattenObjectResponse testFlattenObjectParam(FlattenObjectRequest request);

  FluentSetterFlattenObjectResponse testFluentSetterFlattenObjectParam(FluentSetterFlattenObjectRequest request);

  MultiLayerObjectParam testMultiLayerObjectParam(MultiLayerObjectParam request);

  RecursiveObjectParam testRecursiveObjectParam(RecursiveObjectParam request);

  List<GenericObjectParam<List<RecursiveObjectParam>>> testListObjectParam(
      List<GenericObjectParam<List<RecursiveObjectParam>>> request);

  Map<String, GenericObjectParam<Map<String, GenericObjectParam<RecursiveObjectParam>>>> testMapObjectParam(
      Map<String, GenericObjectParam<Map<String, GenericObjectParam<RecursiveObjectParam>>>> request);
}
